MCD inheritance_weak
CONTRAT ( #num prof, date contrat, salaire horaire contrat )

- Le champ num prof fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré à partir de l'entité PROFESSEUR pour renforcer l'identifiant.
- Le champ date contrat fait partie de la clé primaire de la table. C'était déjà un identifiant de l'entité CONTRAT.
- Le champ salaire horaire contrat était déjà un simple attribut de l'entité CONTRAT.

PROFESSEUR ( num prof, nom prof, prénom prof, téléphone prof, statut vacataire?, date embauche salarié?, échelon salarié?, salaire salarié? )

- Le champ num prof constitue la clé primaire de la table. C'était déjà un identifiant de l'entité PROFESSEUR.
- Les champs nom prof, prénom prof et téléphone prof étaient déjà de simples attributs de l'entité PROFESSEUR.
- Le champ à saisie facultative statut vacataire a migré à partir de l'entité-fille VACATAIRE (supprimée).
- Le champ à saisie facultative date embauche salarié a migré à partir de l'entité-fille SALARIÉ (supprimée).
- Le champ à saisie facultative échelon salarié a migré à partir de l'entité-fille SALARIÉ (supprimée).
- Le champ à saisie facultative salaire salarié a migré à partir de l'entité-fille SALARIÉ (supprimée).